"""
Exceptions used by appdaemon

"""


class RequestHandlerException(Exception):
    pass


class NamespaceException(Exception):
    pass


class DomainException(Exception):
    pass


class ServiceException(Exception):
    pass


class AppException(Exception):
    pass


class HandlerException(Exception):
    pass


class TimeOutException(Exception):
    pass
